<img src="https://raw.githubusercontent.com/antimatter15/lambdu/master/logo.png" alt="eigensheep"/>

# eigensheep
massively parallel experimentation with jupyter



# Goals

    pip3 install eigensheep

Open Jupyter

    import eigensheep

Follow instructions to set up.
